@@ -20,6 +20,7 @@
 #include "juliasession.h"
 
 #include <KProcess>
+#include <KLocalizedString>
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
@@ -35,7 +36,6 @@
 #include "juliaextensions.h"
 #include "juliabackend.h"
 #include "juliacompletionobject.h"
-#include <julia_version.h>
 
 using namespace Cantor;
 
@@ -47,20 +47,30 @@ JuliaSession::JuliaSession(Cantor::Backend *backend)
     setVariableModel(new JuliaVariableModel(this));
 }
 
+JuliaSession::~JuliaSession()
+{
+    if (m_process)
+    {
+        m_process->kill();
+        m_process->deleteLater();
+        m_process = nullptr;
+    }
+}
+
 void JuliaSession::login()
 {
+    if (m_process)
+        return;
     emit loginStarted();
 
-    if (m_process) {
-        m_process->deleteLater();
-    }
-
     m_process = new KProcess(this);
-    m_process->setOutputChannelMode(KProcess::SeparateChannels);
+    m_process->setOutputChannelMode(KProcess::OnlyStdoutChannel);
 
     (*m_process)
         << QStandardPaths::findExecutable(QLatin1String("cantor_juliaserver"));
 
+    connect(m_process, &QProcess::errorOccurred, this, &JuliaSession::reportServerProcessError);
+
     m_process->start();
 
     m_process->waitForStarted();
@@ -113,16 +123,23 @@ void JuliaSession::login()
 
     changeStatus(Session::Done);
     emit loginDone();
-    qDebug() << "login to julia " << JULIA_VERSION_STRING << "done";
+    qDebug() << "login to julia done";
 }
 
 void JuliaSession::logout()
 {
-    m_process->terminate();
+    if(!m_process)
+        return;
 
-    variableModel()->clearVariables();
+    if(status() == Cantor::Session::Running)
+        interrupt();
 
-    changeStatus(Status::Disable);
+    if (m_process->pid())
+        m_process->terminate();
+    m_process->deleteLater();
+    m_process = nullptr;
+
+    Session::logout();
 }
 
 void JuliaSession::interrupt()
@@ -130,7 +147,9 @@ void JuliaSession::interrupt()
     if (expressionQueue().isEmpty())
         return;
 
-    if (m_process->pid()) {
+    if (m_process && m_process->pid())
+    {
+        disconnect(m_process, &QProcess::errorOccurred, this, &JuliaSession::reportServerProcessError);
         m_process->kill();
     }
 
@@ -189,6 +208,25 @@ void JuliaSession::onResultReady()
     finishFirstExpression(true);
 }
 
+void JuliaSession::reportServerProcessError(QProcess::ProcessError serverError)
+{
+    switch(serverError)
+    {
+        case QProcess::Crashed:
+            emit error(i18n("Julia process stopped working."));
+            break;
+
+        case QProcess::FailedToStart:
+            emit error(i18n("Failed to start Julia process."));
+            break;
+
+        default:
+            emit error(i18n("Communication with Julia process failed for unknown reasons."));
+            return;
+    }
+}
+
+
 void JuliaSession::runFirstExpression()
 {
     Cantor::Expression* expr = expressionQueue().first();
