@@ -59,8 +59,12 @@ private Q_SLOTS:
     void testInformationRequest();
     void testHelpRequest();
     void testSyntaxHelp();
+    void testCompletion();
 
     void testVariableModel();
+
+    void testLoginLogout();
+    void testRestartWhileRunning();
 private:
     QString backendName() override;
 };
