@@ -26,7 +26,6 @@
 #include "textresult.h"
 
 #include "settings.h"
-#include "octave-backend-config.h"
 #include "octavehighlighter.h"
 
 #include <KProcess>
@@ -54,12 +53,24 @@ m_previousPromptNumber(1),
 m_syntaxError(false)
 {
     setVariableModel(new OctaveVariableModel(this));
-    qDebug() << octaveScriptInstallDir;
+}
+
+OctaveSession::~OctaveSession()
+{
+    if (m_process)
+    {
+        m_process->kill();
+        m_process->deleteLater();
+        m_process = nullptr;
+    }
 }
 
 void OctaveSession::login()
 {
     qDebug() << "login";
+    if (m_process)
+        return;
+
     emit loginStarted();
 
     m_process = new KProcess ( this );
@@ -75,18 +86,13 @@ void OctaveSession::login()
     args << QLatin1String("PS2('CANTOR_OCTAVE_BACKEND_SUBPROMPT:\\#> ');");
 
     // Add the cantor script directory to octave script search path
-    bool isScriptDirExists = QDir(octaveScriptInstallDir).exists();
-    if (isScriptDirExists)
-        args << QLatin1String("--eval") <<QString::fromLatin1("addpath \"%1\";").arg(octaveScriptInstallDir);
-
     const QStringList& scriptDirs = locateAllCantorFiles(QLatin1String("octavebackend"), QStandardPaths::LocateDirectory);
-    if (scriptDirs.isEmpty() && !isScriptDirExists)
+    if (scriptDirs.isEmpty())
         qCritical() << "Octave script directory not found, needed for integrated plots";
     else
     {
         for (const QString& dir : scriptDirs)
-            if (dir != octaveScriptInstallDir)
-                args << QLatin1String("--eval") << QString::fromLatin1("addpath \"%1\";").arg(dir);
+            args << QLatin1String("--eval") << QString::fromLatin1("addpath \"%1\";").arg(dir);
     }
 
     // Do not show extra text in help commands
@@ -138,8 +144,8 @@ void OctaveSession::logout()
 
     disconnect(m_process, nullptr, this, nullptr);
 
-    // if(status()==Cantor::Session::Running)
-    // TODO: terminate the running expressions first
+    if(status() == Cantor::Session::Running)
+        interrupt();
 
     m_process->write("exit\n");
     qDebug()<<"send exit command to octave";
@@ -149,17 +155,15 @@ void OctaveSession::logout()
         m_process->kill();
         qDebug()<<"octave still running, process kill enforced";
     }
+    m_process->deleteLater();
+    m_process = nullptr;
 
     expressionQueue().clear();
-    delete m_process;
-    m_process = nullptr;
 
     m_output.clear();
     m_previousPromptNumber = 1;
 
-    variableModel()->clearVariables();
-
-    changeStatus(Status::Disable);
+    Session::logout();
 
     qDebug()<<"logout done";
 }
@@ -170,7 +174,7 @@ void OctaveSession::interrupt()
     if(!expressionQueue().isEmpty())
     {
         qDebug()<<"interrupting " << expressionQueue().first()->command();
-        if(m_process->state() != QProcess::NotRunning)
+        if(m_process && m_process->state() != QProcess::NotRunning)
         {
 #ifndef Q_OS_WIN
             const int pid=m_process->pid();
