@@ -24,18 +24,15 @@
 #include <libqalculate/Unit.h>
 
 #include <KColorScheme>
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
+#include <QLocale>
+#include <QDebug>
 
 QalculateHighlighter::QalculateHighlighter(QObject* parent)
     : Cantor::DefaultHighlighter(parent)
 {
 }
 
-QalculateHighlighter::~QalculateHighlighter()
-{
-}
-
 void QalculateHighlighter::highlightBlock(const QString& text)
 {
     if ( text.isEmpty() || text.trimmed().isEmpty() || text.startsWith(QLatin1String(">>> "))
@@ -55,7 +52,7 @@ void QalculateHighlighter::highlightBlock(const QString& text)
 
     CALCULATOR->beginTemporaryStopMessages();
 
-    const QString decimalSymbol = KLocale::global()->decimalSymbol();
+    const QString decimalSymbol = QLocale().decimalPoint();
 
     for ( int i = 0; i < words.size(); ++i, pos += count ) {
         count = words[i].size();
@@ -72,7 +69,7 @@ void QalculateHighlighter::highlightBlock(const QString& text)
             qDebug() << "function";
             format = functionFormat();
         } else if ( isOperatorAndWhitespace(words[i]) ) {
-            // stuff like ") * (" is an invalid expression, but acutally OK
+            // stuff like ") * (" is an invalid expression, but actually OK
 
             // check if last number is actually a float
             bool isFloat = false;
@@ -101,7 +98,7 @@ void QalculateHighlighter::highlightBlock(const QString& text)
                 format = numberFormat();
             }
         } else {
-            MathStructure expr = CALCULATOR->parse(words[i].toAscii().constData());
+            MathStructure expr = CALCULATOR->parse(words[i].toLatin1().constData());
             if ( expr.isNumber() || expr.isNumber_exp() ) {
                 qDebug() << "number";
                 format = numberFormat();
